==> blesta-5.10.2.zip: blesta/plugins/order/language/uk_ua/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Email для відновлення (необов\'язково)';
$lang['Signup.!error.email.blacklist'] = 'Наразі ваше замовлення не може бути оброблене.';
$lang['Signup.index.signup_btn'] = 'Створити обліковий запис';
$lang['Signup.index.continue_btn'] = 'Продовжити оформлення замовлення';
$lang['Signup.index.login_btn'] = 'Увійдіть в систему';
$lang['Signup.index.field_receive_email_marketing'] = 'Я хочу отримувати електронні листи про нові продукти, послуги та пропозиції.';
$lang['Signup.index.field_confirmpassword'] = 'Підтвердити пароль';
$lang['Signup.index.field_newpassword'] = 'Пароль';
$lang['Signup.index.field_password'] = 'Пароль';
$lang['Signup.index.field_username'] = 'Ім\'я користувача';
$lang['Signup.index.field_action_signup'] = 'Створіть обліковий запис';
$lang['Signup.index.field_action_login'] = 'Увійдіть в систему';
$lang['Signup.index.field_action_continue'] = 'Продовжити як %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Вкажіть ім\'я користувача';
$lang['Signup.index.field_username_type_email'] = 'Використовуйте email як ім\'я користувача';
$lang['Signup.index.field_email'] = 'Електронна пошта';
$lang['Signup.index.field_fax'] = 'Факс';
$lang['Signup.index.field_phone'] = 'Телефон';
$lang['Signup.index.field_title'] = 'Назва';
$lang['Signup.index.field_country'] = 'Країна';
$lang['Signup.index.field_zip'] = 'Поштовий індекс';
$lang['Signup.index.field_state'] = 'Штат/провінція';
$lang['Signup.index.field_city'] = 'Місто';
$lang['Signup.index.field_address2'] = 'Адреса 2';
$lang['Signup.index.field_address1'] = 'Адреса 1';
$lang['Signup.index.field_company'] = 'Компанія/Організація.';
$lang['Signup.index.field_lastname'] = 'Прізвище';
$lang['Signup.index.field_firstname'] = 'Ім\'я та прізвище';
$lang['Signup.index.field_taxid'] = 'ІПН / ПДВ';
$lang['Signup.!notice.email_verification'] = 'Було надіслано повідомлення з проханням підтвердити вашу електронну адресу. Будь ласка, завершіть перевірку якнайшвидше.';
$lang['Signup.!notice.force_email_usernames'] = 'Ваше ім\'я користувача буде таким самим, як і ваша електронна адреса.';
$lang['Signup.!error.not_client_owner'] = 'Щоб продовжити, ви повинні увійти в систему як власник клієнта.';
$lang['Signup.!error.captcha.invalid'] = 'Введена капча була невірною. Будь ласка, спробуйте ще раз.';

==> blesta-5.11.4.zip: blesta/plugins/order/language/uk_ua/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Email для відновлення (необов\'язково)';
$lang['Signup.!error.email.blacklist'] = 'Наразі ваше замовлення не може бути оброблене.';
$lang['Signup.index.signup_btn'] = 'Створити обліковий запис';
$lang['Signup.index.continue_btn'] = 'Продовжити оформлення замовлення';
$lang['Signup.index.login_btn'] = 'Увійдіть в систему';
$lang['Signup.index.field_receive_email_marketing'] = 'Я хочу отримувати електронні листи про нові продукти, послуги та пропозиції.';
$lang['Signup.index.field_confirmpassword'] = 'Підтвердити пароль';
$lang['Signup.index.field_newpassword'] = 'Пароль';
$lang['Signup.index.field_password'] = 'Пароль';
$lang['Signup.index.field_username'] = 'Ім\'я користувача';
$lang['Signup.index.field_action_signup'] = 'Створіть обліковий запис';
$lang['Signup.index.field_action_login'] = 'Увійдіть в систему';
$lang['Signup.index.field_action_continue'] = 'Продовжити як %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Вкажіть ім\'я користувача';
$lang['Signup.index.field_username_type_email'] = 'Використовуйте email як ім\'я користувача';
$lang['Signup.index.field_email'] = 'Електронна пошта';
$lang['Signup.index.field_fax'] = 'Факс';
$lang['Signup.index.field_phone'] = 'Телефон';
$lang['Signup.index.field_title'] = 'Назва';
$lang['Signup.index.field_country'] = 'Країна';
$lang['Signup.index.field_zip'] = 'Поштовий індекс';
$lang['Signup.index.field_state'] = 'Штат/провінція';
$lang['Signup.index.field_city'] = 'Місто';
$lang['Signup.index.field_address2'] = 'Адреса 2';
$lang['Signup.index.field_address1'] = 'Адреса 1';
$lang['Signup.index.field_company'] = 'Компанія/Організація.';
$lang['Signup.index.field_lastname'] = 'Прізвище';
$lang['Signup.index.field_firstname'] = 'Ім\'я та прізвище';
$lang['Signup.index.field_taxid'] = 'ІПН / ПДВ';
$lang['Signup.!notice.email_verification'] = 'Було надіслано повідомлення з проханням підтвердити вашу електронну адресу. Будь ласка, завершіть перевірку якнайшвидше.';
$lang['Signup.!notice.force_email_usernames'] = 'Ваше ім\'я користувача буде таким самим, як і ваша електронна адреса.';
$lang['Signup.!error.not_client_owner'] = 'Щоб продовжити, ви повинні увійти в систему як власник клієнта.';
$lang['Signup.!error.captcha.invalid'] = 'Введена капча була невірною. Будь ласка, спробуйте ще раз.';
$lang['Signup.otp.field_submit'] = 'Увійдіть в систему';
$lang['Signup.otp.field_otp'] = 'Одноразовий пароль';
$lang['Signup.otp.login_heading'] = 'Увійдіть в систему';
$lang['Signup.otp.description'] = 'Будь ласка, введіть свій одноразовий пароль.';
$lang['Signup.otp.page_title'] = 'Увійдіть в систему';
$lang['Signup.index.field_agree_tos'] = 'Я прочитав та погоджуюсь з <a href="%1$s" target="_blank">Умовами</a> та положеннями';
$lang['Signup.!error.invalid_agree_tos'] = 'Ви повинні підтвердити свою згоду з умовами та положеннями.';
